@@ -14,12 +14,16 @@ driller = CVEDriller()
 def get_test_cases():
     test_cases = []
 
-    for starting_detail_dir in inputs_folder.iterdir():
-        for filename in starting_detail_dir.iterdir():
-            output_path = Path(outputs_folder, filename.parent.name, filename.stem + ".json")
+    for cwe_dir in inputs_folder.iterdir():
+        if not cwe_dir.is_dir():
+            continue
 
-            if output_path.exists():
-                test_cases.append((filename, output_path))
+        for starting_detail_dir in cwe_dir.iterdir():
+            for filename in starting_detail_dir.iterdir():
+                output_path = Path(outputs_folder, cwe_dir.name, starting_detail_dir.name, filename.stem + ".json")
+
+                if output_path.exists():
+                    test_cases.append((filename, output_path))
 
     return test_cases
 
@@ -34,5 +38,6 @@ def test_extraction(input_file, expected_output_file):
 
     starting_detail, extracted_data = driller(input_text)
 
+    assert starting_detail is not None, f"Starting detail not found in {input_file}"
     assert starting_detail.value == expected_output_file.parent.name, f"Starting detail mismatch in {input_file}"
     assert extracted_data == expected_details, f"Pattern mismatch in {input_file}"
